pub struct RequestClient<E> { /* private fields */ }

Implementations

source

impl<E: From<Error> + From<Error>> RequestClient<E>

source

pub fn new(transport: Transport, validate_fn: Box<ValidateResponseFn<E>>) -> Self

Creates a new RequestClient with a specified transport and a function to validate each response.

source

pub async fn get(&self, endpoint: impl AsRef<str>) -> Result<Response<Body>, E>

Make a GET request to the endpoint and return the response.

source

pub async fn get_string(&self, endpoint: impl AsRef<str>) -> Result<String, E>

Make a GET request to the endpoint and return the response as a string.

source

pub async fn get_json<T: DeserializeOwned>( &self, endpoint: impl AsRef<str> ) -> Result<T, E>

Make a GET request to the endpoint and return the response as a JSON deserialized object.

source

pub fn get_stream<'client>( &'client self, endpoint: impl AsRef<str> + 'client ) -> impl Stream<Item = Result<Bytes, E>> + 'client

Make a GET request to the endpoint and return a stream of byte chunks.

source

pub fn get_json_stream<'client, T>( &'client self, endpoint: impl AsRef<str> + 'client ) -> impl Stream<Item = Result<T, E>> + 'clientwhere T: DeserializeOwned,

Make a GET request to the endpoint and return a stream of JSON chunk results.

source

pub async fn post<B>( &self, endpoint: impl AsRef<str>, body: Payload<B>, headers: Option<Headers> ) -> Result<Response<Body>, E>where B: Into<Body>,

Make a POST request to the endpoint and return the response.

source

pub async fn post_string<B>( &self, endpoint: impl AsRef<str>, body: Payload<B>, headers: Option<Headers> ) -> Result<String, E>where B: Into<Body>,

Make a POST request to the endpoint and return the response as a string.

source

pub async fn post_json<B, T>( &self, endpoint: impl AsRef<str>, body: Payload<B>, headers: Option<Headers> ) -> Result<T, E>where T: DeserializeOwned, B: Into<Body>,

Make a POST request to the endpoint and return the response as a JSON deserialized value.

source

pub fn post_stream<'client, B>( &'client self, endpoint: impl AsRef<str> + 'client, body: Payload<B>, headers: Option<Headers> ) -> impl Stream<Item = Result<Bytes, E>> + 'clientwhere B: Into<Body> + 'client,

Make a straeming POST request to the endpoint and return a stream of byte chunks.

Use post_into_stream if the endpoint returns JSON values.

source

pub fn post_into_stream<'client, B, T>( &'client self, endpoint: impl AsRef<str> + 'client, body: Payload<B>, headers: Option<Headers> ) -> impl Stream<Item = Result<T, E>> + 'clientwhere B: Into<Body> + 'client, T: DeserializeOwned,

Make a streaming POST request to the endpoint and return a stream of JSON deserialized chunks.

source

pub async fn post_upgrade_stream<'client, B>( &'client self, endpoint: impl AsRef<str> + 'client, body: Payload<B> ) -> Result<impl AsyncRead + AsyncWrite + 'client, E>where B: Into<Body> + 'client,

source

pub async fn put<B>( &self, endpoint: impl AsRef<str>, body: Payload<B> ) -> Result<Response<Body>, E>where B: Into<Body>,

Make a PUT request to the endpoint and return the response.

source

pub async fn put_string<B>( &self, endpoint: impl AsRef<str>, body: Payload<B> ) -> Result<String, E>where B: Into<Body>,

Make a PUT request to the endpoint and return the response as a string.

source

pub async fn delete( &self, endpoint: impl AsRef<str> ) -> Result<Response<Body>, E>

Make a DELETE request to the endpoint and return the response.

source

pub async fn delete_string(&self, endpoint: impl AsRef<str>) -> Result<String, E>

Make a DELETE request to the endpoint and return the response as a string.

source

pub async fn delete_json<T: DeserializeOwned>( &self, endpoint: impl AsRef<str> ) -> Result<T, E>

Make a DELETE request to the endpoint and return the response as a JSON deserialized object.

source

pub async fn head(&self, endpoint: impl AsRef<str>) -> Result<Response<Body>, E>

Make a HEAD request to the endpoint and return the response.