Module tarball
containers_
api
0.9.0
Module tarball
Module Items
Functions
In crate containers_
api
containers_api
Module
tarball
Utility functions to compression.
Functions

dir
Writes a gunzip encoded tarball to
buf
from entries found in
path
.
dir_par
par-compress
and (Android or FreeBSD or Linux)
Same as
dir
but initializes the underlying buffer, returns it and utilizes compression parallelization on multiple cores to speed up the work.