Function containers_api::tarball::dir_par
source · pub fn dir_par<P>(path: P) -> Result<Vec<u8>>where
P: AsRef<Path>,Expand description
Same as dir but initializes the underlying buffer, returns it and utilizes compression
parallelization on multiple cores to speed up the work.